//  IoT電子工作キット sLab-Remo2
//  5-1.人を検知してリモコン制御とメール送信 (IFTTT)

// ①ライブラリを読み込み
#include <WiFiClientSecure.h>
// ②ピン配置とグローバル変数定義
const byte LED_PIN  = 12;       // LED制御
const byte IR_S_PIN = 32;       // リモコン送信制御
const byte MOTN_SNR = 17;       // 人感センサのピン設定
bool motionCheck = true;        // 感知チェックON
// ③リモコン送信データを設定
unsigned short irData[] = { 347,172,40, ... ,41,175 };  // ### 【データ書換が必要】 ###

// ④Wi-Fi設定
const char *ssid      = "##### SSID #####";
const char *password  = "### PASSWORD ###";
IPAddress ip(192, 168, 1, 123);     // IPアドレス（本機が利用するIP）
IPAddress gateway(192, 168, 1, 1);  // デフォルトゲートウェイ
IPAddress subnet(255, 255, 255, 0); // サブネットマスク
IPAddress DNS(192, 168, 1, 1);      // DNSサーバ
WiFiClientSecure client;      // TLSを利用するためクライアント変数定義

// ⑤IFTTT設定
const char *iftttHost  = "maker.ifttt.com"; // IFTTT Server
const char *iftttEvent = "iotMail";// IFTTT Event
const char *iftttKey   = "##### IFTTT-KEY #####";// IFTTT Key
const char *ifttt_ca_cert = \
"-----BEGIN CERTIFICATE-----\n" \
"MIIGpzCCBY+gAwIBAgIIW2O1ayPtDEEwDQYJKoZIhvcNAQELBQAwgbQxCzAJBgNV\n" \
"BAYTAlVTMRAwDgYDVQQIEwdBcml6b25hMRMwEQYDVQQHEwpTY290dHNkYWxlMRow\n" \
"GAYDVQQKExFHb0RhZGR5LmNvbSwgSW5jLjEtMCsGA1UECxMkaHR0cDovL2NlcnRz\n" \
"LmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvMTMwMQYDVQQDEypHbyBEYWRkeSBTZWN1\n" \
"cmUgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IC0gRzIwHhcNMTgwOTA2MTcwMDE1WhcN\n" \
"MjAwOTI4MjIxMzU0WjA5MSEwHwYDVQQLExhEb21haW4gQ29udHJvbCBWYWxpZGF0\n" \
"ZWQxFDASBgNVBAMMCyouaWZ0dHQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n" \
"MIIBCgKCAQEA8c1HRaRBFWER/SG2eXN++ykWLSoCyJ1xcxOXy15Bk57WXGLIBZHn\n" \
"Y8/SN+H1KuUcN40KC35NuGhaQP43cELcBSG/BiYTlFPIAizauX2K9VZh+zWhwkgq\n" \
"y8bJ5+yvZKH5gwqNL248Y4gjwaPeU8o2K1xrFYWSfM/7kFQFul2goWOA3HIn5qE3\n" \
"NUsgxF8uLh2BSuJKQF73WDvM1zE86MIU20M9+PEo/pV5orIPZX/54cAZgXnr+59t\n" \
"KPL14Rl9qqTiptMJC8y2CIqKC9zHBwIwX4uYPOquom1oqAuItWgqAJwtC3z5a20r\n" \
"wbI2eNbDPdbeweT/4RtCjTwKlQuHmzeLbwIDAQABo4IDNTCCAzEwDAYDVR0TAQH/\n" \
"BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwDgYDVR0PAQH/BAQD\n" \
"AgWgMDcGA1UdHwQwMC4wLKAqoCiGJmh0dHA6Ly9jcmwuZ29kYWRkeS5jb20vZ2Rp\n" \
"ZzJzMS04NjUuY3JsMF0GA1UdIARWMFQwSAYLYIZIAYb9bQEHFwEwOTA3BggrBgEF\n" \
"BQcCARYraHR0cDovL2NlcnRpZmljYXRlcy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5\n" \
"LzAIBgZngQwBAgEwdgYIKwYBBQUHAQEEajBoMCQGCCsGAQUFBzABhhhodHRwOi8v\n" \
"b2NzcC5nb2RhZGR5LmNvbS8wQAYIKwYBBQUHMAKGNGh0dHA6Ly9jZXJ0aWZpY2F0\n" \
"ZXMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS9nZGlnMi5jcnQwHwYDVR0jBBgwFoAU\n" \
"QMK9J47MNIMwojPX+2yz8LQsgM4wIQYDVR0RBBowGIILKi5pZnR0dC5jb22CCWlm\n" \
"dHR0LmNvbTAdBgNVHQ4EFgQUTv/uQ1GFjIW3WdcM3sn8fwtzoKQwggF9BgorBgEE\n" \
"AdZ5AgQCBIIBbQSCAWkBZwB1AKS5CZC0GFgUh7sTosxncAo8NZgE+RvfuON3zQ7I\n" \
"DdwQAAABZa/TxpgAAAQDAEYwRAIgdYZfhny1zdZj9H560jR5UrHgRn3ICcW1InPx\n" \
"zw8neN4CIEWuBSawq4hAhcBLMnfi+PW2OIj2J0WSMGSG9kxmpE4xAHYA7ku9t3XO\n" \
"YLrhQmkfq+GeZqMPfl+wctiDAMR7iXqo/csAAAFlr9PLqwAABAMARzBFAiA5I3ux\n" \
"1COAWE65DzDJUkG1KCdtlFD3XqLhjhozKthb9AIhAKIql04vTpqM5swE5YoO539r\n" \
"IUILnDZREGEYznWgKB13AHYAXqdz+d9WwOe1Nkh90EngMnqRmgyEoRIShBh1loFx\n" \
"RVgAAAFlr9PMhQAABAMARzBFAiBN0mgVDHNItBVC0zu85QRgcdJWmHPkzkp0un6x\n" \
"W6Mc4wIhALjsHONTT0w4kdik30ajXRZO82iTypNiLL+HNMRfsCJjMA0GCSqGSIb3\n" \
"DQEBCwUAA4IBAQBfJREWuoH4U1MIbufLfnkcuj5dfOcwwvCeUUQWibb97Xf0dvG6\n" \
"iGuYkJYLIHsf7d8eH7iHpWw/nJTu7P2XMwj4nohIzE6rxt7Ab/6ma6j/0sV2Vbx4\n" \
"aSloxa/6zXcZ1T/UlQqtD7PLNNcFDJYACQeo8BYzSsCO6HSpltBrbaRYNAvn1Dbo\n" \
"F73XIMqc/K60UGehrMYV/9D0/cTyk6Z6OtLXnUxD9kgYugR06drmQ6a0anJETcCS\n" \
"Bsa/pZc1HMb34v0eOz7UB2Eo0V4Qnng3ulzVajS5crRvO1lR/flg5Pv+YMmucreQ\n" \
"Dy8rstIiWXEa6liRoKEPIg3QDTcL3pfhSXty\n" \
"-----END CERTIFICATE-----\n" \
"-----BEGIN CERTIFICATE-----\n" \
"MIIE0DCCA7igAwIBAgIBBzANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UEBhMCVVMx\n" \
"EDAOBgNVBAgTB0FyaXpvbmExEzARBgNVBAcTClNjb3R0c2RhbGUxGjAYBgNVBAoT\n" \
"EUdvRGFkZHkuY29tLCBJbmMuMTEwLwYDVQQDEyhHbyBEYWRkeSBSb290IENlcnRp\n" \
"ZmljYXRlIEF1dGhvcml0eSAtIEcyMB4XDTExMDUwMzA3MDAwMFoXDTMxMDUwMzA3\n" \
"MDAwMFowgbQxCzAJBgNVBAYTAlVTMRAwDgYDVQQIEwdBcml6b25hMRMwEQYDVQQH\n" \
"EwpTY290dHNkYWxlMRowGAYDVQQKExFHb0RhZGR5LmNvbSwgSW5jLjEtMCsGA1UE\n" \
"CxMkaHR0cDovL2NlcnRzLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvMTMwMQYDVQQD\n" \
"EypHbyBEYWRkeSBTZWN1cmUgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IC0gRzIwggEi\n" \
"MA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC54MsQ1K92vdSTYuswZLiBCGzD\n" \
"BNliF44v/z5lz4/OYuY8UhzaFkVLVat4a2ODYpDOD2lsmcgaFItMzEUz6ojcnqOv\n" \
"K/6AYZ15V8TPLvQ/MDxdR/yaFrzDN5ZBUY4RS1T4KL7QjL7wMDge87Am+GZHY23e\n" \
"cSZHjzhHU9FGHbTj3ADqRay9vHHZqm8A29vNMDp5T19MR/gd71vCxJ1gO7GyQ5HY\n" \
"pDNO6rPWJ0+tJYqlxvTV0KaudAVkV4i1RFXULSo6Pvi4vekyCgKUZMQWOlDxSq7n\n" \
"eTOvDCAHf+jfBDnCaQJsY1L6d8EbyHSHyLmTGFBUNUtpTrw700kuH9zB0lL7AgMB\n" \
"AAGjggEaMIIBFjAPBgNVHRMBAf8EBTADAQH/MA4GA1UdDwEB/wQEAwIBBjAdBgNV\n" \
"HQ4EFgQUQMK9J47MNIMwojPX+2yz8LQsgM4wHwYDVR0jBBgwFoAUOpqFBxBnKLbv\n" \
"9r0FQW4gwZTaD94wNAYIKwYBBQUHAQEEKDAmMCQGCCsGAQUFBzABhhhodHRwOi8v\n" \
"b2NzcC5nb2RhZGR5LmNvbS8wNQYDVR0fBC4wLDAqoCigJoYkaHR0cDovL2NybC5n\n" \
"b2RhZGR5LmNvbS9nZHJvb3QtZzIuY3JsMEYGA1UdIAQ/MD0wOwYEVR0gADAzMDEG\n" \
"CCsGAQUFBwIBFiVodHRwczovL2NlcnRzLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkv\n" \
"MA0GCSqGSIb3DQEBCwUAA4IBAQAIfmyTEMg4uJapkEv/oV9PBO9sPpyIBslQj6Zz\n" \
"91cxG7685C/b+LrTW+C05+Z5Yg4MotdqY3MxtfWoSKQ7CC2iXZDXtHwlTxFWMMS2\n" \
"RJ17LJ3lXubvDGGqv+QqG+6EnriDfcFDzkSnE3ANkR/0yBOtg2DZ2HKocyQetawi\n" \
"DsoXiWJYRBuriSUBAA/NxBti21G00w9RKpv0vHP8ds42pM3Z2Czqrpv1KrKQ0U11\n" \
"GIo/ikGQI31bS/6kA1ibRrLDYGCD+H1QQc7CoZDDu+8CL9IVVO5EFdkKrqeKM+2x\n" \
"LXY2JtwE65/3YR8V3Idv7kaWKK2hJn0KCacuBKONvPi8BDAB\n" \
"-----END CERTIFICATE-----\n" \
;

void setup() {
  // ⑥Serial設定
  Serial.begin(115200);
  Serial.println ( );
  // ⑦ピンモード設定
  pinMode ( LED_PIN,  OUTPUT );
  pinMode ( IR_S_PIN, OUTPUT );
  pinMode ( MOTN_SNR, INPUT);
  // ⑧無線Wi-Fi接続
  WiFi.config( ip, gateway, subnet, DNS );  // DNSがないとHTTPS接続不可
  WiFi.begin ( ssid, password );
  // ⑨Wi-Fi接続処理（接続するまで無限ループ）
  bool ledFlag = true;
  while ( WiFi.status() != WL_CONNECTED ) {
    // ⑩LEDを１秒毎に点滅する
    ledFlag = !ledFlag;
    digitalWrite(LED_PIN, ledFlag);
    delay ( 1000 );
    Serial.print ( "." );
  }
  // ⑪Wi-Fi接続できたのでシリアルモニターにIPアドレス表示
  Serial.print ( "Wi-Fi Connected! IP address: " );
  Serial.println ( WiFi.localIP() );
  digitalWrite ( LED_PIN, true );
  // ⑫HTTPS用の証明書を設定
  client.setCACert(ifttt_ca_cert);
}

// ⑬１秒毎に人感センサーで感知したらリモコンとメール送信
void loop() {
  delay(1000);
  // ⑭感知チェック、かつ、モーションセンサー感知状態
  if (motionCheck && digitalRead(MOTN_SNR)) {
    Serial.println( "Detected!" );
    motionCheck = false;        // ⑮感知フラグOFF
    irSend ();                  // ⑯赤外線送信する関数を実行
    iftttMail ();               // ⑰IFTTTでメール送信
  } else {
    Serial.println( "No detected." );
    motionCheck = true;         // ⑱感知チェックON
  }
}

// ⑲赤外線送信処理
void irSend () {
  // ⑳ローカル変数定義
  unsigned short irCount = 0; // HIGH,LOWの信号数
  unsigned long l_now = 0;    // 送信開始時間を保持
  unsigned long sndt = 0;     // 送信開始からの経過時間
  // ㉑HIGH,LOWの信号数を計算
  irCount = sizeof(irData) / sizeof(irData[0]);
  // ㉒送信開始時間を取得
  l_now = micros();
  // ㉓0,1の信号回数分をFor文でループ
  for (int i = 0; i < irCount; i++) {
    // ㉔送信開始からの信号終了時間を計算
    sndt += irData[i];
    do {
      // ㉕iが偶数なら赤外線ON、奇数ならOFFのまま
      // ㉖キャリア周波数38kHz(約26μSec周期の半分)でON時間で送信
      digitalWrite(IR_S_PIN, !(i&1));
      microWait(13);
      // ㉗キャリア周波数38kHz(約26μSec周期の半分)でOFF時間で送信
      digitalWrite(IR_S_PIN, 0);
      microWait(13);
    // ㉘送信開始からの信号終了時間が超えるまでループ
    } while (long(l_now + (sndt * 10) - micros()) > 0);
  }
}

// ㉙マイクロ秒単位で待つ
void microWait(signed long waitTime) {
  unsigned long waitStartMicros = micros();
  // ㉚指定されたマイクロ秒が経過するまでWhileでループ処理（待つ）
  while (micros() - waitStartMicros < waitTime) {};
}

// ㉛赤外線送信処理
void iftttMail () {
  // ㉜URL決定 maker.ifttt.com/trigger/{event}/with/key/{key}
  String value1 = "Motion is detected!";
  String pathUrl = "/trigger/" + String(iftttEvent) + "/with/key/" + String(iftttKey);
  String json = "{\"value1\":\"" + value1 + "\"}";
  delay(10);
  // ㉝LED消灯（処理中が判別できるように消灯している）
  digitalWrite(LED_PIN, false);// 処理中はLED消灯
  // ㉞HTTPS接続と結果判定
  if (!client.connect(iftttHost, 443)) {
    // ㉟HTTPS接続失敗時のシリアルモニタ表示
    Serial.println("Connection failed!");
  } else {
    // ㊱HTTPS接続成功時のシリアルモニタ表示
    Serial.println("Connected to ifttt!\n");
    // ㊲HTTPSデータ送信処理
    client.println("POST https://" + String( iftttHost ) + pathUrl + " HTTP/1.1");
    client.println("Host: " + String(iftttHost) + ":443");
    client.println("Content-Type: application/json");
    client.println("Connection: Keep-Alive");
    client.println("Content-Length: "+ String(json.length()));
    client.println("");
    client.println(json);
    // ㊳HTTPS接続確認
    if (client.connected()) {
      // ㊴ヘッダの受信表示処理
      Serial.println("--- Header ---");
      while (1) {
        String line = client.readStringUntil('\n');
        Serial.println(line);
        if (line == "\r") {
          break; // ヘッダの末尾は\r\nのため、\r時に終了
        }
      }
      // ㊵本文(Body)の受信表示処理
      Serial.println("--- Body ---");
      while (client.available()) {
        char c = client.read();
        Serial.write(c);
      }
    }
    // ㊶HTTPS通信の終了
    client.stop();
  }
  // ㊷終了処理（LED点灯、シリアルモニタ表示）
  digitalWrite(LED_PIN, true);
  Serial.println("ifttt end");
}
