//  IoT電子工作キット
//  5-3.AIスピーカ連携スマートリモコン（屋外スマホ対応）

// ①ライブラリ、Configファイルを読み込み
#include <WiFiClientSecure.h>
#include <EEPROM.h>
#include <SPIFFS.h>
#include <ESPAsyncWebServer.h>
#include <PubSubClient.h>
#include <ArduinoJson.h>
#include "config.h"

// ②利用ライブラリの設定を変更（PubSubClientライブラリは128バイトなのを拡張）
#define MQTT_MAX_PACKET_SIZE 1024

// ③Wi-Fi、MQTTクライアントを設定
WiFiClientSecure wifiClient;
AsyncWebServer webServer ( 80 );
PubSubClient mqttClient(host, 8883, wifiClient);

void setup(void) {
  // ④Serial設定
  Serial.begin(115200);
  Serial.println ( );
  // ⑤SPIFFS開始
  SPIFFS.begin();
  // ⑥EEPROM開始（サイズ指定：ボタン名10個分[65*10]）
  EEPROM.begin(650);
  // ⑦ピンモード設定
  pinMode ( LED_PIN,  OUTPUT );
  pinMode ( IR_R_PIN, INPUT );
  pinMode ( IR_S_PIN, OUTPUT );
  // ⑧Wi-Fi接続処理
  setup_wifi();
  // ⑨WebServer設定処理
  setup_webserver();
}

// ⑩無線Wi-Fi設定
void setup_wifi() {
  // ⑪無線Wi-Fi情報設定
  Serial.println ( "Wi-Fi SetUp" );
  WiFi.config( ip, gateway, subnet, DNS );  // DNSがないとMQTT接続不可
  WiFi.begin ( ssid, password );
  // ⑫Wi-Fi接続処理（接続するまで無限ループ）
  while ( WiFi.status() != WL_CONNECTED ) {
    // ⑬LEDを１秒毎に点滅する
    ledFlag = !ledFlag;
    digitalWrite(LED_PIN, ledFlag);
    // ⑭１秒間Wait
    delay ( 1000 );
    Serial.print ( "." );
  }
  // ⑮Wi-Fi接続できたのでシリアルモニターにIPアドレス表示
  Serial.print ( "Wi-Fi Connected! IP address: " );
  Serial.println ( WiFi.localIP() );
  // ⑯LED点灯（Wi-Fi接続状態）
  digitalWrite ( LED_PIN, true );
  // ⑰クライアントにCA証明書を設定
  wifiClient.setCACert(beebottle_ca_cert);
}

void loop(void){
  // ⑱MQTT状態を確認し接続状態でなかったらMQTT接続処理
  if (!mqttClient.connected()) {
    reconnect();
  }
  // ⑲MQTTクライアント処理
  mqttClient.loop();
}

// ⑳MQTT接続処理
void reconnect() {
  // ㉑MQTT接続状態までループ処理
  while (!mqttClient.connected()) {
    Serial.println("Attempting MQTT connection...");
    // ㉒MQTT設定情報定義
    String username = "token:";
    username += channelToken;
    // ㉓MQTT接続処理
    mqttClient.connect(clientID, username.c_str(), NULL);
    delay(2000);
  }
  Serial.println("MQTT connected");
  // ㉔MQTTメッセージ受信時の処理設定
  mqttClient.setCallback(callback);
  // ㉕MQTTメッセージを受信するTOPICの設定
  mqttClient.subscribe(topic);
}

// ㉖MQTTメッセージ受信時の処理
void callback(char* topic, byte* payload, unsigned int length) {
  // ㉗MQTT受信メッセージを変数に保存
  char recvData[MQTT_MAX_PACKET_SIZE];
  snprintf(recvData, sizeof(recvData), "%s", payload);
  // ㉘MQTT受信メッセージをシリアルモニタ表示
  Serial.print("Message arrived [");
  Serial.print(topic);
  Serial.println("] ");
  Serial.println(recvData);
  // ㉙受信データのJSON形式を解析し変数へ保存
  StaticJsonBuffer<MQTT_MAX_PACKET_SIZE> jsonBuffer;
  JsonObject& jsonBuf = jsonBuffer.parseObject(recvData);
  // ㉚JSON形式解析が成功しなかったらエラー表示し終了
  if (!jsonBuf.success()) {
    Serial.println("parseObject() failed");
    return;
  }
  // ㉛受信データ（data）を取得保存
  const char* parsedPayload = jsonBuf["data"];
  // ㉜受信データ（data）が存在するか判定
  if (parsedPayload != NULL) {
    Serial.print("payload: ");
    Serial.println(parsedPayload);
    // ㉝受信データ（data）に送信リモコン番号
    if (contRemocon( parsedPayload )) {
      Serial.println("MQTT send OK");
    } else {
      Serial.println("MQTT send NG");
    }
  }
}
