// ①onloadは画面が読み込まれた時に実行
window.onload = function () {
  // ②アクセスしているURLを取得しページ判定（例：http://192.168.1.123:12193/set）
  var url = window.location.href;
  var urlarr = url.split("/");
  // ③設定ページでない場合にIF文内を処理
  if ( urlarr[3].indexOf("set") == -1 ) {
    // ④温・湿・照度情報の更新処理実行
    updateTemp();
  }
  // ⑤リモコンボタン情報の更新処理実行
  updateIr();
}

// ⑥温・湿・照度情報取得・表示
function updateTemp() {
  // ⑦HTTPリクエストを作成
  var xhr = new XMLHttpRequest();
  // ⑧アクセスしているURLを取得し同じホスト(Port)取得（例：http://192.168.1.123:12193/getrem）
  var url = window.location.href;
  var urlarr = url.split("/");
  // ⑨同じホスト(Port)へデータ取得アクセスURIを設定
  url = "http://" + urlarr[2] + "/gettemp";
  // ⑩タイムアウト処理時の処理
  xhr.timeout = 5000; // ５秒
  xhr.ontimeout = function(e){
    document.getElementById('dispStatus').innerHTML = "<b>本体へのアクセスが失敗</b>";
  };
  // ⑪HTTP GETアクセス
  xhr.open("GET", url);
  xhr.send("");
  // ⑫応答時の処理
  xhr.addEventListener("load",function(ev){
      // ⑬応答データを取得しJSONデータを解析してgeRecvに保存
      var resGeStr = xhr.responseText;
      var geRecv =  JSON.parse(resGeStr);
      // ⑭受信データ（温度情報）が存在するか確認
      if ( geRecv.t != "" ) {
        // ⑮Webページに温・湿・照度情報を表示
        document.getElementById('curTemp').innerHTML = "<b><font size=+1>" + geRecv.t + "</font></b> ℃";
        document.getElementById('curHum').innerHTML = "<b><font size=+1>" + geRecv.h + "</font></b> ％";
        document.getElementById('curLig').innerHTML = "<b><font size=+1>" + geRecv.l + "</font></b>";
      }
  });
}

// ⑯リモコンボタン情報取得・表示
function updateIr() {
  var xhr = new XMLHttpRequest();
  var url = window.location.href;
  var urlarr = url.split("/");
  // ⑰アクセスURL作成（例：http://192.168.1.123:12193/getrem）
  url = "http://" + urlarr[2] + "/getrem";
  xhr.timeout = 5000; 
  xhr.ontimeout = function(e){
    document.getElementById('dispStatus').innerHTML = "<b>本体へのアクセスが失敗</b>";
  };
  xhr.open("GET", url);
  xhr.send("");
  xhr.addEventListener("load",function(ev){
    var resGtStr = xhr.responseText;
    var gtRecv =  JSON.parse(resGtStr);
    // ⑱ボタン10個分のデータを確認
    for ( i=0 ; i<10 ; i++) {
      // ⑲受信データ（ボタン名）が存在するか確認
      if ( gtRecv[i] != "" && typeof gtRecv[i] !== "undefined" ) {
        var idname = "spn" + i;
        if ( document.getElementById(idname) != null ) {
          // ⑳"spn0-9"が存在した場合（制御画面）にボタン名を入力
          document.getElementById(idname).innerHTML = gtRecv[i];
        } else {
          // ㉑"spn0-9"が存在しない場合（設定画面）にボタン名を"ir0-9"に入力
          idname = "ir" + i;
          document.getElementById(idname).value = gtRecv[i];
        }
      } else {
        // ㉒"btn0-9"が存在した場合（制御画面）でボタン名がなければボタンを無効化
        var idname = "btn" + i;
        if ( document.getElementById(idname) != null ) {
          document.getElementById(idname).disabled = true;
        }
      }
    }
  });
}

// ㉓グローバル変数を定義（送受信の関数で利用）
irFlg=false;    // 受信処理中フラグ（true:処理中、false:処理可能）
flgRed=true;    // 状態表示の表示・非表示フラグ
count=0;        // １秒毎にカウントしタイムアウト判定用
rcvTimer=15;    // タイムアウト秒数

// ㉔リモコン信号処理
function snd(setNum) {
  // ㉕処置中判定
  if (irFlg) {
    // ㉖処置中の場合は処理中表示し終了
    document.getElementById('dispStatus').innerHTML = "<b>処理中です</b>";
    return;
  }
  // ㉗処置フラグを処理中とし、受信中表示処理実施
  irFlg=true;
  document.getElementById('dispStatus').innerHTML = "<b>リモコン送信中</b>";
  var xhr = new XMLHttpRequest();
  var url = window.location.href;
  var urlarr = url.split("/");
  // ㉘アクセスURL作成（例：http://192.168.1.123:12193/cntrem?n=1）
  url = "http://" + urlarr[2] + "/cntrem?n=" + setNum;
  xhr.timeout = 5000;
  xhr.ontimeout = function(e){
    dispfail();
  };
  xhr.open("GET", url);
  xhr.send("");
  xhr.addEventListener("load",function(ev){
    var resStr = xhr.responseText;
      // ㉙OKを受信したらif文内を状態表示。それ以外はelse内を状態表示
    if ( resStr.indexOf("OK") != -1 ) {
      document.getElementById('dispStatus').innerHTML = "<b>リモコン送信しました。</b>";
    } else {
      document.getElementById('dispStatus').innerHTML = "<b>リモコン送信に失敗しました。</b>";
    }
    // ㉚処置フラグを戻す
    irFlg=false;
  });
}

// ㉛リモコン受信処理
function rcv(setNum){
  // ㉜処理カウンタリセット
  count = 0;
  // ㉝処置中判定
  if (irFlg) {
    // ㉞処置中の場合は処理中表示し終了
    document.getElementById('dispStatus').innerHTML = "<b>処理中です</b>";
    return;
  }
  // ㉟処置フラグを処理中とし、受信中表示処理実施
  irFlg=true;
  setMsgTenmetu();
  // ㊱入力したボタン名を取得
  var idname = "ir" + setNum;
  var setName = document.getElementById(idname).value;
  // ㊲受信設定処理へ本体へアクセス
  var xhr = new XMLHttpRequest();
  var url = window.location.href;
  var urlarr = url.split("/");
  url = "http://" + urlarr[2] + "/setrem?n=" + setNum + "&a=" + setName;
  xhr.timeout = rcvTimer * 1000;
  xhr.ontimeout = function(e){
    dispfail();
  };
  xhr.open("GET", url);
  xhr.send("");
  xhr.addEventListener("load",function(ev){
    var resStr = xhr.responseText;
    // ㊳OKを受信したらif文内を状態表示。それ以外はelse内を状態表示
    if ( resStr.indexOf("OK") != -1 ) {
      // ㊴フラグを受信完了へ。状態表示に完了表示
      irFlg=false;
      document.getElementById('dispStatus').innerHTML = "<b>リモコン設定が完了しました。</b>";
    } else {
      // ㊵失敗表示
      dispfail();
    }
  });
}

// ㊶状態表示の点滅処理（リモコン受信中）
function setMsgTenmetu(){
  // ㊷受信完了していない。かつ、タイムアウト前
  if (irFlg == true && count < rcvTimer )　{    // 受信完了してなければ
    // ㊸flgRedで１秒毎にIF文内とelse文内を交互に表示（受信中を点滅）
    if(flgRed){
      document.getElementById('dispStatus').innerHTML = "<b>リモコン受信中（" + rcvTimer + "秒間）</b>";
    }else{
      document.getElementById('dispStatus').innerHTML = "<br>";
    }
    // ㊹状態表示状態を反転
    flgRed=!flgRed;
    // ㊺１秒後に、再度setMsgTenmetu()を実行
    setTimeout("setMsgTenmetu()",1000);
    count++;
  // ㊻タイムアウトしていた場合は失敗処理へ
  } else if (count >= rcvTimer) {
    dispfail(); 
  }
}

// ㊼失敗時の表示
function dispfail(){
  // ㊽点滅しないようにタイマーアウトにカウントを合わせる
  count=rcvTimer;
  irFlg=false;
  // ㊾状態に失敗を表示
  document.getElementById('dispStatus').innerHTML = "<b>リモコン受信に失敗しました。</b>";
}

