//  IoT電子工作キット sLab-Remo2
//  6-2.カメラ付スマートリモコン

// ①ライブラリの読み込み
#include <WiFi.h>
#include <EEPROM.h>
#include <SPIFFS.h>
#include <Wire.h>
#include "ESPAsyncWebServer.h"
#include "WebSocketsServer.h"
#include "OV7670.h"

// ####################### ②Wi-Fi設定(環境設定) #######################
const char *ssid      = "##### SSID #####";
const char *password  = "### PASSWORD ###";
IPAddress ip(192, 168, 1, 123);  // IPアドレス（本機が利用するIP）
IPAddress gateway(192, 168, 1, 1);  // デフォルトゲートウェイ
IPAddress subnet(255, 255, 255, 0); // サブネットマスク
// ###################################################################

// ③ピン配置
const byte LED_PIN  = 16;  // LED緑
const byte IR_R_PIN =  5;  // リモコン受信
const byte IR_S_PIN = 12;  // リモコン送信

// ④カメラピン配置
const camera_config_t cam_conf = {
  .D0 = 36,
  .D1 = 39,
  .D2 = 34,
  .D3 = 35,
  .D4 = 32,
  .D5 = 33,
  .D6 = 25,
  .D7 = 26,
  .XCLK = 15,   // ★27利用時 Wi-Fi接続不可
  .PCLK = 14,
  .VSYNC = 13,
  .xclk_freq_hz = 10000000,     // XCLK 10MHz
  .ledc_timer   = LEDC_TIMER_0,
  .ledc_channel = LEDC_CHANNEL_0 
};

// ⑤カメラ解像度指定
#define CAM_RES     QCIF    // カメラ解像度
#define CAM_WIDTH   176     // カメラ幅
#define CAM_HEIGHT  144     // カメラ高さ
#define CAM_DIV       1     // １画面分割数

// ⑥グローバル変数宣言
OV7670 cam;                 // camera
AsyncWebServer webServer(80);  // WebサーバPort80番
WebSocketsServer webSocket = WebSocketsServer(81);
uint8_t clientNum;
struct st_remocon {
  char remo_name[65];
};
unsigned short irData[1500];

bool wsFlag  = false;       // WebSocket状態フラグ(true:接続状態、false:未接続状態)
bool ledFlag = true;        // LED制御フラグ
int dataSize = 2 * CAM_WIDTH * CAM_HEIGHT;      // カメラデータ: 2 * 176 * 144 = 50688 [Byte]
uint8_t wsCamData[50688];   // カメラデータを保持

// ⑦Arduino初期設定処理
void setup() {
  // ⑧処理開始
  Serial.begin(115200);
  Serial.println("sLab-Remo2 Sart"); 
  SPIFFS.begin();    // SPIFFS開始
  EEPROM.begin(650); // EEPROM開始（サイズ指定：ボタン名10個分[65*10]）
  // ⑨Wire開始、端子設定
  Wire.begin();
  Wire.setClock(400000);
  pinMode ( LED_PIN, OUTPUT );
  pinMode ( IR_R_PIN, INPUT );
  pinMode ( IR_S_PIN, OUTPUT );

  // ⑩無線Wi-Fi接続
  Serial.println ( "Wi-Fi SetUp" );
  WiFi.config( ip, gateway, subnet );
  WiFi.begin ( ssid, password );
  while ( WiFi.status() != WL_CONNECTED ) { // 接続するまで無限ループ処理
    // ⑪接続中はLEDを１秒毎に点滅する
    ledFlag = !ledFlag;
    digitalWrite(LED_PIN, ledFlag);
    delay ( 1000 );
    Serial.print ( "." );
  }
  // ⑫Wi-Fi接続完了（IPアドレス表示）
  Serial.print ( "Wi-Fi Connected! IP address: " );
  Serial.println ( WiFi.localIP() );
  // ⑬Wi-Fi接続時はLED点灯（Wi-Fi接続状態）
  digitalWrite ( LED_PIN, true );

  // ⑭カメラ初期化処理
  Serial.println( "cam init" );  
  esp_err_t err = cam.init(&cam_conf, CAM_RES, RGB565);
  if(err != ESP_OK){
    Serial.print( "cam.init ERR:" );
    Serial.println(err);
    // ⑮失敗時は15秒後に再起動しRetry
    delay(15000);
    ESP.restart();
  }
  cam.vflip( false );

  // ⑯WebServer設定処理
  setup_webserver();
  // ⑰WebSocket起動
  webSocket.begin();
  webSocket.onEvent(onWebSocketEvent);
  Serial.println("##### setup completed #####");
}

// ⑱Arduinoループ処理（通常時はこの処理）
void loop(void) {
  // ⑲WebSocket処理
  webSocket.loop();
  // ⑳WebSocket接続判定
  if (wsFlag) {
    // ㉑カメラデータ読み込み処理
    cam.getLines( 1 , wsCamData , CAM_HEIGHT);
    // ㉒映像データ送信処理
    webSocket.sendBIN(clientNum, wsCamData, dataSize);
  }
}
