// グローバル変数宣言
var wsUri;
var socket = null;
var tms;
var msg;
var ctx;
var width;
var height;
var imageData;
var pixels;
var fps = 0;
var canFlag = false;
var wsFlag = false;

// onloadは画面が読み込まれた時に実行
window.onload = function () {
  // リモコン情報更新
  updateIr();
  // WebSocket情報更新
  var fullpath = window.location.href;
  var urlarr = fullpath.split("/");
  if ( urlarr[3].indexOf("set") == -1 ) {
    wsUri = "ws://" + window.location.hostname + ":81/";
    msg = document.getElementById('msg');
    var canv = document.getElementById('ccanvas');
    ctx = canv.getContext('2d');
    width = canv.width;
    height = canv.height;
    imageData = ctx.createImageData( width, 1 );
    pixels = imageData.data;
    var path = fullpath.split('?');
    if ( path[1] && path[1] != "" ) {
      var eachData = path[1].split('&');
      for (var i = 0; i < eachData.length; i++) {
        var tmpData = eachData[i].split('=');
        if ( tmpData[0] == "camera" && tmpData[1] == "on" ) {
          canFlag = true;
          canDisp(1);
        }
      }
    }
    if (canFlag) {
      document.getElementById("startbtn").disabled = true;
      setTimeout('wsConnect()', 1000);
    }
  }
}

// 映像通信メッセージ処理
function Msg(message){ msg.innerHTML = message;}
// 映像通信接続処理
function wsConnect(){
  wsFlag = true;
  document.getElementById("startbtn").disabled = true;
  tms = new Date();
  if(socket == null){
    socket = new WebSocket(wsUri);
    socket.binaryType = 'arraybuffer';
    socket.onopen   = function(evt){ onOpen(evt) };
    socket.onclose  = function(evt){ onClose(evt) };
    socket.onmessage = function(evt){ onMessage(evt) };
    socket.onerror  = function(evt){ onError(evt) };
  }
}
// 映像通信終了処理
function wsDisconnect(){
  wsFlag = false;
  socket.close();
  socket = null;
  Msg('STOP');
  document.getElementById("startbtn").disabled = false;
}
// 映像通信Open処理
function onOpen(evt){ Msg('START');}
// 映像通信Close処理
function onClose(evt){
  Msg('DISCONNECT');
  wsClose();
  document.getElementById("startbtn").disabled = false;
}
// 映像通信エラー処理
function onError(evt){
  Msg('Err:' + evt.data);
  document.getElementById("startbtn").disabled = false;
}
// 映像通信処理
function onMessage(evt){
  var data = evt.data;
  if( typeof data == 'string'){
    msg.innerHTML = data;
  }else if( data instanceof ArrayBuffer){
    drawLine(evt.data);
  }else if( data instanceof Blob){
    Msg('Blob data received');
  }
}
// 映像通信終了
function wsClose(){
  socket.close();
  socket = null;
  if (wsFlag) {
    setTimeout('wsConnect()', 1);
  }
}
// 映像画像表示
function drawLine(data){
  var buf = new Uint16Array(data);
  for(var y = 0; y < (buf.length)/width; y+=1){
    var base = 0;
    for(var x = 0; x < width; x += 1){
      var c = x + y * width;
      pixels[base+0] = (buf[c] & 0xf800) >> 8 | (buf[c] & 0xe000) >> 13;
      pixels[base+1] = (buf[c] & 0x07e0) >> 3 | (buf[c] & 0x0600) >> 9;
      pixels[base+2] = (buf[c] & 0x001f) << 3 | (buf[c] & 0x001c) >> 2;
      pixels[base+3] = 255;
      base += 4;
    }
    ctx.putImageData(imageData, 0, y);
  }
  if(y == height) fps+=1;
}
// 映像状態表示
function canDisp(chgFlag) {
  if (chgFlag == 0) {
    document.getElementById("dcan1").style.display="none";
    document.getElementById("dcan2").style.display="inline";
  } else {
    document.getElementById("dcan1").style.display="block";
    document.getElementById("dcan2").style.display="none";
  }
  document.getElementById("chkCan1").checked = true;
  document.getElementById("chkCan2").checked = false;
}

// リモコンボタン情報取得・表示
function updateIr() {
  var xhr = new XMLHttpRequest();
  var url = window.location.href;
  var urlarr = url.split("/");
  // アクセスURL作成（例：http://192.168.1.123:12193/getrem）
  url = "http://" + urlarr[2] + "/getrem";
  xhr.timeout = 5000; 
  xhr.ontimeout = function(e){
    document.getElementById('dispStatus').innerHTML = "<b>本体へのアクセスが失敗</b>";
  };
  xhr.open("GET", url);
  xhr.send("");
  xhr.addEventListener("load",function(ev){
    var resGtStr = xhr.responseText;
    var gtRecv =  JSON.parse(resGtStr);
    // ボタン10個分のデータを確認
    for ( i=0 ; i<10 ; i++) {
      // 受信データ（ボタン名）が存在するか確認
      if ( gtRecv[i] != "" && typeof gtRecv[i] !== "undefined" ) {
        var idname = "spn" + i;
        if ( document.getElementById(idname) != null ) {
          // "spn0-9"が存在した場合（制御画面）にボタン名を入力
          document.getElementById(idname).innerHTML = gtRecv[i];
        } else {
          // "spn0-9"が存在しない場合（設定画面）にボタン名を"ir0-9"に入力
          idname = "ir" + i;
          document.getElementById(idname).value = gtRecv[i];
        }
      } else {
        // "btn0-9"が存在した場合（制御画面）でボタン名がなければボタンを無効化
        var idname = "btn" + i;
        if ( document.getElementById(idname) != null ) {
          document.getElementById(idname).disabled = true;
        }
      }
    }
  });
}

// グローバル変数を定義（送受信の関数で利用）
irFlg=false;    // 受信処理中フラグ（true:処理中、false:処理可能）
flgRed=true;    // 状態表示の表示・非表示フラグ
count=0;        // １秒毎にカウントしタイムアウト判定用
rcvTimer=15;    // タイムアウト秒数

// リモコン信号処理
function snd(setNum) {
  // 処置中判定
  if (irFlg) {
    // 処置中の場合は処理中表示し終了
    document.getElementById('dispStatus').innerHTML = "<b>処理中です</b>";
    return;
  }
  // 処置フラグを処理中とし、受信中表示処理実施
  irFlg=true;
  document.getElementById('dispStatus').innerHTML = "<b>リモコン送信中</b>";
  var xhr = new XMLHttpRequest();
  var url = window.location.href;
  var urlarr = url.split("/");
  // アクセスURL作成（例：http://192.168.1.123:12193/cntrem?n=1）
  url = "http://" + urlarr[2] + "/cntrem?n=" + setNum;
  xhr.timeout = 5000;
  xhr.ontimeout = function(e){
    dispfail();
  };
  xhr.open("GET", url);
  xhr.send("");
  xhr.addEventListener("load",function(ev){
    var resStr = xhr.responseText;
    // OKを受信したらif文内を状態表示。それ以外はelse内を状態表示
    if ( resStr.indexOf("OK") != -1 ) {
      document.getElementById('dispStatus').innerHTML = "<b>リモコン送信しました。</b>";
    } else {
      document.getElementById('dispStatus').innerHTML = "<b>リモコン送信に失敗しました。</b>";
    }
    // 処置フラグを戻す
    irFlg=false;
  });
}

// リモコン受信処理
function rcv(setNum){
  // 処理カウンタリセット
  count = 0;
  // 処置中判定
  if (irFlg) {
    // 処置中の場合は処理中表示し終了
    document.getElementById('dispStatus').innerHTML = "<b>処理中です</b>";
    return;
  }
  // 処置フラグを処理中とし、受信中表示処理実施
  irFlg=true;
  setMsgTenmetu();
  // 入力したボタン名を取得
  var idname = "ir" + setNum;
  var setName = document.getElementById(idname).value;
  // 受信設定処理へ本体へアクセス
  var xhr = new XMLHttpRequest();
  var url = window.location.href;
  var urlarr = url.split("/");
  url = "http://" + urlarr[2] + "/setrem?n=" + setNum + "&a=" + setName;
  xhr.timeout = rcvTimer * 1000;
  xhr.ontimeout = function(e){
    dispfail();
  };
  xhr.open("GET", url);
  xhr.send("");
  xhr.addEventListener("load",function(ev){
    var resStr = xhr.responseText;
    // OKを受信したらif文内を状態表示。それ以外はelse内を状態表示
    if ( resStr.indexOf("OK") != -1 ) {
      // フラグを受信完了へ。状態表示に完了表示
      irFlg=false;
      document.getElementById('dispStatus').innerHTML = "<b>リモコン設定が完了しました。</b>";
    } else {
      // 失敗表示
      dispfail();
    }
  });
}

// 状態表示の点滅処理（リモコン受信中）
function setMsgTenmetu(){
  // 受信完了していない。かつ、タイムアウト前
  if (irFlg == true && count < rcvTimer )　{    // 受信完了してなければ
    // flgRedで１秒毎にIF文内とelse文内を交互に表示（受信中を点滅）
    if(flgRed){
      document.getElementById('dispStatus').innerHTML = "<b>リモコン受信中（" + rcvTimer + "秒間）</b>";
    }else{
      document.getElementById('dispStatus').innerHTML = "<br>";
    }
    // 状態表示状態を反転
    flgRed=!flgRed;
    // １秒後に、再度setMsgTenmetu()を実行
    setTimeout("setMsgTenmetu()",1000);
    count++;
  // タイムアウトしていた場合は失敗処理へ
  } else if (count >= rcvTimer) {
    dispfail(); 
  }
}

// 失敗時の表示
function dispfail(){
  // 点滅しないようにタイマーアウトにカウントを合わせる
  count=rcvTimer;
  irFlg=false;
  // 状態に失敗を表示
  document.getElementById('dispStatus').innerHTML = "<b>リモコン受信に失敗しました。</b>";
}