// ログインチェック処理
void doLogin(AsyncWebServerRequest *request) {
  // 本体保存データを取得
  String loginid = cnflogid;
  String loginps = cnflogps;
  // EEPROMを利用する設定の場合
  if (loginid == "eeprom" && loginps == "eeprom") {
    // EEPROMの値を取得
    st_logRom logRom;
    EEPROM.get<st_logRom>(1001, logRom);
    // データが保存されているかCheck
    if (logRom.logid[0] == 'O' && logRom.logid[1] == ':' ) {
      String tmploginid = String(logRom.logid);
      String tmploginps = String(logRom.logps);
      // データ長が１Byte以上ある場合
      if (tmploginid.length() > 2 && tmploginps.length() > 0) {
        loginid = tmploginid.substring(2,tmploginid.length());
        loginps = tmploginps;
      }
    }
  }
  Serial.println ( "IoT LoginID:" +  loginid + ",Pass:" + loginps);
  // 送信されたID,パスワードを取得
  String inputid = request->getParam("id")->value();
  String inputps = request->getParam("pass")->value();
  String time1 = logptime(1);                     // 時間文字列を取得（現在時間）
  String time2 = logptime(2);                     // 時間文字列を取得（前後30秒許容）
  String hashedid1 = loginid + time1;             // 時間文字列を追加（現在時間）
  String hashedid2 = loginid + time2;             // 時間文字列を追加（前後30秒許容）
  String hashedpass1 = loginps + time1;           // 時間文字列を追加（現在時間）
  String hashedpass2 = loginps + time2;           // 時間文字列を追加（前後30秒許容）
  hashedid1   = sha2s(hashedid1);                 // IDをハッシュ化（現在時間）
  hashedid2   = sha2s(hashedid2);                 // IDをハッシュ化（前後30秒許容）
  hashedpass1 = sha2s(hashedpass1);               // パスワードをハッシュ化（現在時間）
  hashedpass2 = sha2s(hashedpass2);               // パスワードをハッシュ化（前後30秒許容）
  IPAddress cliIp = request->client()->remoteIP();// アクセス端末IPを取得
  Serial.println ( "LoginCheck:" +  inputid + ":" + hashedid1 + ":" + hashedid2 + ":" + inputps + ":" + hashedpass1 + ":" + hashedpass2);
  // ID、パスワード一致をチェック
  if ( (inputid == hashedid1 || inputid == hashedid2) && (inputps == hashedpass1 || inputps == hashedpass2) ) {
    // ログインOK時の処理
    logintime = nowtime;         // ログイン時間を保持
    loginFlag = true;            // ログイン状態を変更（ログイン状態）
    loginIp = cliIp.toString();  // ログイン端末IPを保存
    Serial.println ( "LoginOK:" +  loginIp);
    logNgCount = 0;              // ログイン失敗カウンタをクリア
    request->send(200, "text/plain", "OK");
  } else {
    // ログインNG時の処理
    loginFlag = false;           // ログイン状態を変更（ログアウト状態）
    loginIp = "";                // ログイン端末IPをクリア
    Serial.println ( "LoginNG:" +  cliIp.toString());
    request->send(200, "text/plain", "NG");
    logNgCount++;                // ログイン失敗カウンタを増加
    // ３回連続して誤ると３０秒フリーズ
    if (logNgCount >= 3) {
      delay(30000);
    }
  }
}

// ログインID,パスワード設定
void setLogin(String inputid_org, String inputps) {
  // LoginIDに識別用文字"O:"を先頭に付与
  String inputid = "O:" + inputid_org;
  // EEPROMに保存
  st_logRom logRom;
  inputid.toCharArray(logRom.logid, inputid.length()+1);
  inputps.toCharArray(logRom.logps, inputps.length()+1);
  EEPROM.put<st_logRom>(1001, logRom);
  EEPROM.commit();
  // 処理完了のOKを送信
  Serial.println ( "setLogin OK:" +  inputid_org + ":" +  inputps);
}

// ログイン状態のチェック
bool checkLogin(IPAddress cliIp) {
  // ログイン状態とアクセスIPをチェック
  if (loginFlag && loginIp == cliIp.toString()) {
    logintime = nowtime;
    return true;
  } else {
    return false;
  }
}

// ハッシュ化計算
String sha2s(String orgWord){
  char payload[orgWord.length()+1];
  orgWord.toCharArray(payload, (orgWord.length()+1));
  byte shaResult[32];
  mbedtls_md_context_t ctx;
  mbedtls_md_type_t md_type = MBEDTLS_MD_SHA256;
  const size_t payloadLength = strlen(payload);
  mbedtls_md_init(&ctx);
  mbedtls_md_setup(&ctx, mbedtls_md_info_from_type(md_type), 0);
  mbedtls_md_starts(&ctx);
  mbedtls_md_update(&ctx, (const unsigned char *) payload, payloadLength);
  mbedtls_md_finish(&ctx, shaResult);
  mbedtls_md_free(&ctx);
  String rtWord = ""; 
  for(int i= 0; i< sizeof(shaResult); i++){
      char str[3];
      sprintf(str, "%02x", (int)shaResult[i]);
      rtWord += String(str);
  }
  return rtWord;
}
