// 赤外線受信（信号受信 or 30秒間を処理）
void setRemocon (AsyncWebServerRequest *request) {
  // 利用する変数を宣言
  unsigned short irCount = 0;   // HIGH,LOWの信号数
  uint32_t lastt = 0;           // 1つ前の経過時間を保持
  uint32_t deltt = 0;           // 1つ前の経過時間を保持
  uint32_t sMilli;              // 本処理の開始時間
  uint32_t wMilli;              // 赤外線の待ち開始時間
  uint32_t sMicro;              // 処理の開始時間
  uint32_t cMicro;              // 現在時間
  bool rState = 0;              // 赤外線受信モジュールの状態 0:LOW,1:HIGH
  // 現在の時間をミリ秒で取得
  sMilli = millis();
  // 特定条件(信号受信 or 30秒経過)するまで無限ループ
  while(1) {
    // Ir受信を待つ開始時間を取得
    wMilli = millis();
    // 反転信号の受信待ち
    while (digitalRead(IR_R_PIN) == rState) {
      // 待ち始めて0.5秒以上経過したら
      if (millis() - wMilli > 500) {
        // 待ち始めて0.5秒以上経過したら
        if ( irCount > 10 ) {
          Serial.println("");
          Serial.println("recvOK!");
          delay(1);
          // ボタン名をEEPROMへ、リモコンデータをファイルへ保存
          //xTaskCreatePinnedToCore(saveIr,"saveIr", 4096, ((irCount - 1), request), 1, NULL, 1); //Task1実行
          if (saveIr( (irCount - 1), request)) {
            // 正常に終了したため、WebサーバからOKを返答
            request->send(200, "text", "OK");
            Serial.println("setRemocon OK");
          } else {
            // 信号保存に失敗したためNGを返答
            request->send(200, "text", "NG");
            Serial.println("setRemocon NG");
          }
          return;    // ⑪正常に完了
        }
        // 0,1信号が10個以上ない場合は雑音のため再度ゼロから受信
        irCount = 0;
      }
      // 処理が15秒以上経過したらタイムアウト
      if ( millis() - sMilli > 15000 ) {
        request->send(200, "text", "NG");// タイムアウトしたのでNGを送信
        Serial.println("setRemocon T.O.");
        return;                          // 15秒経過で処理終了（受信なし）
      }
    }
    // 信号受信開始時の現在の時間や経過時間を取得
    if ( irCount == 0 ) {
      sMicro = micros();
      lastt = 0;
      irCount++;
      Serial.print("ir:");
    // 信号受信処理開始後の処理（irCountが1以上）
    } else {
      // 赤外線受信部の状態変化が最後に変化した時間からの経過時間を計算
      cMicro = micros();
      deltt = ( (cMicro - sMicro)/ 10 ) - lastt;
      irData[(irCount - 1 )] = deltt;
      // 次回経過時間計算のため最後に変化した経過時間を保存
      lastt = lastt + deltt;
      irCount++;
      Serial.print( deltt );
      Serial.print(",");
    }
    // 次回While内で状態変化を検知する値を変更
    rState = !rState;
  }
}

// ボタン名をEEPROMへ、リモコンデータをファイルへ保存
bool saveIr(unsigned short irLength, AsyncWebServerRequest *request){
  String setirname = "";
  String setNumStr = "";
  // ボタン番号の取得とチェック(HTTP GETリクエストのパラメータ)
  if (request->hasParam("n")) {
    setNumStr = request->getParam("n")->value();
  } else {
    return false;
  }
  // ボタン名の取得とチェック(HTTP GETリクエストのパラメータ)
  if (request->hasParam("a")) {
    setirname = request->getParam("a")->value();
  } else {
    return false;
  }
  // ボタン番号をString型をint型へ変換
  int setNum = setNumStr.toInt();
  // ボタン名に識別用文字"O:"を先頭に付与
  setirname = "O:" + setirname;
  // EEPROMに保存用の型が一致した変数を定義
  st_remocon remRom;
  // Stringからchar型に変換（終了文字を付与するためLengthは+1）
  setirname.toCharArray(remRom.remo_name, setirname.length()+1);
  // メモリ位置を計算しEEPROMへ書き込み
  int memPos = (65 * setNum);
  EEPROM.put<st_remocon>(memPos, remRom);
  EEPROM.commit();
  Serial.println("setIr:" + String(setNum) + ":" + setirname);
  // リモコン信号を保存するためファイル名を作成（ファイル名はボタン番号）
  String t_file = "/" + setNumStr;
  Serial.println( "recvFile:" + t_file);
  // ファイルを書き込みモードで開く
  File fw = SPIFFS.open(t_file.c_str(), "w");
  // リモコン信号の長さを最初に書き込み（最初の行）
  fw.println( String( irLength, HEX ) );
  // リモコン信号の0,1の時間長さを書き込み（２行目以降）
  for (int i = 0; i < irLength; i++) {
    fw.println( String( irData[i], HEX ) );
  }
  // 書き込みが完了したのでファイルを閉じる
  fw.close();
  // 正常に処理が完了したのでtrueを返す
  return true;
}

// 赤外線送信処理
bool  contRemocon (String setNumStr) {  // 送信番号保存
  // 変数宣言
  unsigned short irCount = 0; // HIGH,LOWの信号数
  unsigned long l_now = 0;    // 送信開始時間を保持
  unsigned long sndt = 0;     // 送信開始からの経過時間 
  // リモコン信号をファイルから取得（ファイル名はボタン番号）
  String t_file = "/" + setNumStr;
  Serial.println( "sendFile:" + t_file);
  // ファイルを開く
  File fr = SPIFFS.open(t_file.c_str(), "r");
  // ファイルを開く
  if(!fr || fr.isDirectory()){
    Serial.println("FileOpen NG");
    return false;
  }
  // 最初の１行のみ読み出し信号長さ（0,1の数）を取得
  String snum = fr.readStringUntil('\n');
  // １行目の文字列を数値型に変換
  irCount = strtol(snum.c_str(), NULL, 16);
  Serial.print( "sendData:" + String(irCount));
  // 一旦ファイルから変数irDataに読み出し保存
  for (int i = 0; i < irCount; i++) {
    snum = fr.readStringUntil('\n');
    irData[i] = strtol(snum.c_str(), NULL, 16);
    //Serial.print("," + String(irData[i]));
  }
  fr.close();
  // 送信開始時間を取得
  l_now = micros();
  // 0,1の信号回数分をFor文でループ
  for (int i = 0; i < irCount; i++) {
    // 送信開始からの信号終了時間を計算
    sndt += irData[i];
    do {
      // iが偶数なら赤外線ON、奇数ならOFFのまま
      // キャリア周波数38kHz(約26μSec周期の半分)でON時間で送信
      digitalWrite(IR_S_PIN, !(i&1));
      microWait(13);
      // キャリア周波数38kHz(約26μSec周期の半分)でOFF時間で送信
      digitalWrite(IR_S_PIN, 0);
      microWait(13);
    // 送信開始からの信号終了時間が超えるまでループ
    } while (long(l_now + (sndt * 10) - micros()) > 0);
  }
  // 正常に終了したので、trueを返答
  Serial.println(":End");
  return true;
}

// マイクロ秒単位で待つ
void microWait(signed long waitTime) {
  unsigned long waitStartMicros = micros();
  while (micros() - waitStartMicros < waitTime) {};
}
