// WebServer設定処理
void setup_webserver() {
  // ************************** ログイン処理 **************************
  // WebServer処理設定（ログイン画面を送信）
  webServer.on("/login", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "wlogin" );
      request->send(SPIFFS, "/login.html", "text/html");
  });
  // WebServer処理設定（ログアウト処理）
  webServer.on("/logout", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "wlogout" );
      loginFlag = false;
      loginIp = "";
      request->send(SPIFFS, "/login.html", "text/html");
  });
  // WebServer処理設定（ハッシュ関数ファイル送信）
  webServer.on("/sha256-min.js", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "sha.js" );
      request->send(SPIFFS, "/sha256-min.js", "text/html");
  });
  // WebServer処理設定（現在時間の送信）
  webServer.on("/gett", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "get time" );
      String senddata = "{\"iott\":\"" + getcurtime() + "\"}";
      request->send(200, "text/plain", senddata);
  });
  // WebServer処理設定（ファビコン画像送信）
  webServer.on("/favicon.ico", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "favicon" );
      request->send(SPIFFS, "/favicon.ico", "image/x-icon");
  });
  // WebServer処理設定（ログイン処理）
  webServer.on("/dologin", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "dologin" );
      doLogin(request);
  });
  // ************************** ログイン後の処理 **************************
  // WebServer処理設定（TOP[制御]画面を送信）
  webServer.on("/", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "Top" );
      sendSpiffsFile(request, "/top.html");
  });
  // WebServer処理設定（TOP及びリモコン設定Javascriptファイル送信）
  webServer.on("/rem.js", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "rem.js" );
      sendSpiffsFile(request, "/rem.js");
  });
  // WebServer処理設定（リモコン設定画面を送信）
  webServer.on("/set", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "set" );
      sendSpiffsFile(request, "/set.html");
  });
  // WebServer処理設定（ボタン情報送信）
  webServer.on("/getrem", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "getrem" );
      String senddata = getRemocon();
      sendWebText(request, senddata);
  });
  // WebServer処理設定（リモコン受信設定）
  webServer.on("/setrem", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "setrem" );
      if (checkLogin(request->client()->remoteIP())) {
        setRemocon(request);
      } else {
        request->send(200, "text/plain", "NG");
      }
  });
  // WebServer処理設定（リモコン送信）
  webServer.on("/cntrem", HTTP_GET, [](AsyncWebServerRequest *request){
      if (checkLogin(request->client()->remoteIP())) {
        Serial.println ( "cntrem" );
        // ⑩ボタン番号を取得とチェック(HTTP GETリクエストのパラメータ)及び送信処理
        if (request->hasParam("n") && contRemocon( request->getParam("n")->value() )) {
          request->send(200, "text", "OK");
          Serial.println("Web send OK");
        } else {
          request->send(200, "text", "NG");
          Serial.println("Web send NG");
        }
      } else {
        request->send(200, "text/plain", "NG");
      }
  });
  // WebServer処理設定（ログイン設定画面を送信）
  webServer.on("/setlog", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "setlog" );
      sendSpiffsFile(request, "/setlog.html");
  });
  // WebServer処理設定（ログイン設定）
  webServer.on("/dosetlog", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "dosetlog" );
      if (checkLogin(request->client()->remoteIP())) {
        setLogin(request->getParam("id")->value(), request->getParam("pass")->value());
        request->send(200, "text/plain", "OK");
      } else {
        request->send(200, "text/plain", "NG");
      }
  });
  // WebServer開始処理
  DefaultHeaders::Instance().addHeader("Access-Control-Allow-Origin", "*");
  webServer.begin();
  Serial.println ( "Web server started" );
}

// Webサーバ：SPIFFSファイル送信
void sendSpiffsFile(AsyncWebServerRequest *request, String sendFile) {
  if (checkLogin(request->client()->remoteIP())) {
    request->send(SPIFFS, sendFile, "text/html");
  } else {
    request->send(SPIFFS, "/login.html", "text/html");
  }
}

// Webサーバ：テキスト送信
void sendWebText(AsyncWebServerRequest *request, String sendText) {
  if (checkLogin(request->client()->remoteIP())) {
    Serial.println ( "sendWebText:" + sendText );
    request->send(200, "text/plain", sendText);
  } else {
    Serial.println ( "sendText:NG" );
    request->send(200, "text/plain", "NG");
  }
}

// ボタン情報送信関数
String getRemocon() {
  // 送信データを作成(JSON形式)
  String senddata = "{";
  // EEPROMデータを保存する変数を宣言
  st_remocon remRom;
  // ボタン情報10個分を読み出し返答する
  for (byte i = 0; i < 10; i++) {
    // EEPROMメモリ位置を計算
    int memPos = (65 * i);
    // 前回の値'O:'が残らないように消す
    remRom.remo_name[0] = 'n';
    // EEPROMからデータ取得
    EEPROM.get<st_remocon>(memPos, remRom);
    // データが保存されているかCheck
    if (remRom.remo_name[0] == 'O' && remRom.remo_name[1] == ':' ) {
      // 返答文字列長が１を超える場合は","をつける（２つ目以降との区切り）
      if (senddata.length() > 1) {
        senddata += ",";
      }
      // 返答する値を一度String型に置き換える（"O:"を削除するため）
      String getirname = String(remRom.remo_name);
      // 返答文字列作成（"O:"を削除するため2から最後まで）
      senddata += "\"" + (String)i + "\":\"" + getirname.substring(2,getirname.length()) + "\"";
    }
  }
  // 最後にJSONデータを閉じるため"}"をつける
  senddata += "}";
  // リモコン情報表示
  return senddata;
}
